@@ -95,6 +95,52 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CertificateInfoSubmit(self, request):
+        """付费提交证书资料
+
+        :param request: Request instance for CertificateInfoSubmit.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CertificateInfoSubmitRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CertificateInfoSubmitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CertificateInfoSubmit", params, headers=headers)
+            response = json.loads(body)
+            model = models.CertificateInfoSubmitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CertificateOrderSubmit(self, request):
+        """提交付费证书订单
+
+        :param request: Request instance for CertificateOrderSubmit.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CertificateOrderSubmitRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CertificateOrderSubmitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CertificateOrderSubmit", params, headers=headers)
+            response = json.loads(body)
+            model = models.CertificateOrderSubmitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CheckCertificateChain(self, request):
         """本接口（CheckCertificateChain）用于检查证书链是否完整。
 
@@ -141,6 +187,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CheckCertificateExist(self, request):
+        """根据证书内容检测当前账号下是否存在一致的证书， 存在则返回证书ID， 不存在则返回空
+
+        :param request: Request instance for CheckCertificateExist.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateExistRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateExistResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckCertificateExist", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckCertificateExistResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CommitCertificateInformation(self, request):
         """提交证书订单到CA机构。
 
@@ -331,7 +400,7 @@ class SslClient(AbstractClient):
         - 若待部署的证书和传入域名不匹配， 则不会创建成功
         - 若部署clb实例时， 7层监听器下无规则，则不会创建成功
         - 若部署clb实例时， 7层监听器未开启SNI，该监听器下存在任一域名和证书不匹配， 则不会创建成功
-        - 若部署clb实例是，监听器规则为正则表示式， 则不会创建成功
+        - 若部署clb实例时，监听器规则为正则表示式， 则不会创建成功
 
         <dx-alert infotype="explain" title="">一个证书ID，相同的资源类型，只能创建一个部署任务，必须等部署任务执行完成，才能创建新的部署任务</dx-alert>
 
